==> bidmad_flutter_plugin-1.5.1.tar.gz: lib/FlutterBaseBanner.dart <==
import 'package:flutter/services.dart';

class FlutterBaseBanner {
  late String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback;
  var onFailAdCallback;

  FlutterBaseBanner({
    required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> load(int y) async {
    await _platform.invokeMethod('load', {"y":y});
  }

  Future<void> loadWidget() async {
    await _platform.invokeMethod('loadWidget');
  }

  Future<void> setInterval(int sec) async {
    await _platform.invokeMethod('setInterval', {"sec":sec});
  }

  Future<void> setAdInfo(String zoneId) async {
    await _platform.invokeMethod('makeAdView', {"zoneId":zoneId});
  }

  Future<void> hideBanner() async {
    await _platform.invokeMethod('hideBanner');
  }

  Future<void> showBanner() async {
    await _platform.invokeMethod('showBanner');
  }

  Future<void> removeBanner() async {
    await _platform.invokeMethod('removeBanner');
  }

  Future<void> setCallbackListener({
    void Function()? onLoadAd,
    void Function(String errorMsg)? onFailAd
  }) async {

    if(onLoadAd != null){
      onLoadAdCallback = onLoadAd;
    }
    if(onFailAd != null){
      onFailAdCallback = onFailAd;
    }
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    switch (call.method) {
      case 'onLoadAd':
        if (onLoadAdCallback != null) {
          onLoadAdCallback();
        };
        break;
      case 'onFailAd':
        String errorMessage = call.arguments.toString();
        if (onFailAdCallback != null) {
          onFailAdCallback(errorMessage);
        };
        break;
      default:
        throw ('method not defined');
    }
  }
}

==> bidmad_flutter_plugin-1.7.2.tar.gz: lib/FlutterBaseBanner.dart <==
import 'package:flutter/services.dart';

class FlutterBaseBanner {
  late String _channelNm;
  late MethodChannel _platform;

  var onLoadAdCallback;
  var onFailAdCallback;

  FlutterBaseBanner({
    required String channelName
  }){
    this._channelNm = channelName;
    _initChannel(_channelNm);
  }

  Future<void> _initChannel(String channelNm) async {
    _platform = MethodChannel(channelNm);
    _platform.setMethodCallHandler(_handleMethod);
  }

  Future<void> load(int y) async {
    return await _platform.invokeMethod('load', {"y": y});
  }

  Future<void> loadWidget() async {
    return await _platform.invokeMethod('loadWidget');
  }

  Future<void> setInterval(int sec) async {
    return await _platform.invokeMethod('setInterval', {"sec": sec});
  }

  Future<void> setAdInfo(String zoneId) async {
    return await _platform.invokeMethod('makeAdView', {"zoneId": zoneId});
  }

  Future<void> hideBanner() async {
    return await _platform.invokeMethod('hideBanner');
  }

  Future<void> showBanner() async {
    return await _platform.invokeMethod('showBanner');
  }

  Future<void> removeBanner() async {
    return await _platform.invokeMethod('removeBanner');
  }

  Future<void> setCallbackListener({
    void Function()? onLoadAd,
    void Function(String errorMsg)? onFailAd
  }) async {

    if(onLoadAd != null){
      onLoadAdCallback = onLoadAd;
    }
    if(onFailAd != null){
      onFailAdCallback = onFailAd;
    }
  }

  Future<dynamic> _handleMethod(MethodCall call) async {
    switch (call.method) {
      case 'onLoadAd':
        if (onLoadAdCallback != null) {
          onLoadAdCallback();
        }
        break;
      case 'onFailAd':
        String errorMessage = call.arguments.toString();
        if (onFailAdCallback != null) {
          onFailAdCallback(errorMessage);
        }
        break;
      default:
        throw ('method not defined');
    }
  }
}
